@@ -5,7 +5,7 @@ use warnings;
 
 use version; 
 our $VERSION;
-$VERSION = "0.15";
+$VERSION = "0.16";
 
 use Net::SSLeay qw(make_headers get_https);
 use URI;
@@ -19,6 +19,8 @@ use constant {
     DEFAULT_PAGE_SIZE => 100,
 };
 
+# "IPsonar" and "Lumeta" are both registered marks of the Lumeta Corporation.
+
 
 =head1 NAME
 
@@ -26,7 +28,7 @@ IPsonar - Wrapper to interact with the Lumeta IPsonar API
 
 =head1 VERSION
 
-Version 0.15
+Version 0.16
 
 =cut
 
@@ -37,11 +39,15 @@ This module wraps the IPsonar RESTful API.
 It handles the paging and https stuff so you can concentrate on extracting
 information from reports.
 
-Code snippet.
+"Lumeta" and "IPsonar" are both registered trademarks of the Lumeta Coporation
+
+=head1 EXAMPLE
+
+    Script to get all the IP address for all the devices that have
+    port 23 open:
 
     my $rsn = IPsonar->new('rsn_address_or_name','username','password');
     my $test_report = 23;
-    my @ip_list;
 
     my $results = $rsn->query('detail.devices',
         {
@@ -50,7 +56,7 @@ Code snippet.
         }) or die "Problem ".$rsn->error;
 
     while (my $x = $rsn->next_result) {
-        push @ip_list,$x->{ip};
+       print "IP: $x->{ip}\n";
     }
 
 =head1 SUBROUTINES/METHODS
